############
Installation
############

Requirements
============

sageodata_db relies on some specific Python packages to be installed in order to
work. All of these will install themselves automatically using the Python package manager
program pip. The requirements are: 

- cx_Oracle: https://oracle.github.io/python-cx_Oracle/
- pandas: https://pandas.pydata.org/
- python-sa-gwdata: https://github.com/kinverarity1/python-sa-gwdata#python-sa-gwdata
- loguru: https://github.com/Delgan/loguru#readme
- sqlparse: https://github.com/andialbrecht/sqlparse#python-sqlparse---parse-sql-statements

Installing sageodata_db
=======================

You can install this package by running the following command in Command Prompt:

.. code-block::

    pip install sageodata_db

To upgrade to the latest version:

.. code-block::

    pip install -U sageodata_db

The source code is stored on the DEW Water Science Bitbucket account at 
https://bitbucket.org/dewsurfacewater/sageodata_db. You can request access to
this by emailing Claire.Sims@sa.gov.au with your Bitbucket username.
